% Run this script once data has been loaded (e.g. plot_diameters.m) to
% produce the plot.

colors = [230 159 0;
          86 180 233;
          0 158 115;
          240 228 66;
          0 114 178;
          213 94 0;
          204 121 167] ./255;
      
set(gcf,'DefaultAxesColorOrder',colors);
results = plot(data{1:end});

%% Add lines to guide the eye
hold on

for i = 1:length(results)
     x = get(results(i),'XData')';
     y = get(results(i),'YData')';
     
     % linear fit
     a = x\y; % coefficients
     Y = x*a; % fitted y values
     
     % Least squares regression to get error on the slope
     [f, gof] = fit(x, y, fittype({'x'}));
     slope = coeffvalues(f);
     ci = confint(f, 0.99);
     fprintf('%i\t slope = %.3f +/ %.3f\t r^2 = %.3f\n', i, ...
         coeffvalues(f), slope - ci(1), gof.rsquare)
     
     % If the sum of the square of the residuals is above a threshold
     % (which was chosen to give a good guide to the eye) use a smoothing
     % spline, otherwise a straight line.
     if sum((Y-y).^2) > 5000
        ft = fittype('smoothingspline');
        opts = fitoptions( 'Method', 'SmoothingSpline' );
        opts.SmoothingParam = 7.99847110997533e-07;
        [fitresult, gof] = fit( x, y, ft, opts );
        p = plot(fitresult,x,y);
     else
        p = plot(x,Y,'-');
     end
     
     set(p, 'Marker', 'None', 'Color', colors(i,:))
end

%% Apperance
set(gca, 'ylim', [0 2000], 'xlim', [0 1100], 'xtick', 100:300:1000, ...
    'ytick', 100:300:2000)
xlabel('Injection rate of solvent at inlet ({\mu}L/min)')
ylabel('Collection rate at outlet ({\mu}L/min)')
box on

if exist('tit', 'var')
    title(tit)
end

%% Plot line corresponding to perfect separation
guide = plot(get(gca, 'xlim'), get(gca, 'xlim'), 'k-', 'DisplayName', ...
    'Perfect');
