% Figure 3
% Plot graphs showing the volumetric collection rate of liquid at the
% outlet versus volumetric injection rate of solvent at the inlet for (a)
% aqueous?-fluorous, (b) organic?-fluorous, and (c) aqueous?-organic
% systems. Results are shown for flow restrictions of common length l = 5
% cm and inner diameters ranging from 152 to 1000 microns. The black lines
% denote perfect separation in which the collection rate at the outlet is
% equal to the injection rate of solvent at the inlet. The maximum error in
% the volumetric collection rate at the outlet is +/-6 microlitres/min.

% Create figure
figure
pos = get(gcf,'Position');
pos(3:4) = [825 450] * 1.2;
set(gcf, 'position', pos)
h = tight_subplot(1, 3, .02, [0.11 0.1], [.11 .14]);

%% Plot aqueous-fluorous
axes(h(1))
files = dir('results/H2O-HT230*05.mat');
files = files(end:-1:1); % reverse order so legend makes sense
tit = '(a) aqueous-fluorous';
data = cell(length(files), 1);

for i = 1:length(files)
    exp = load(files(i).name);
    data{i} = exp.exp;
end

makeplot
legend OFF
text(1050, 1420, '1000 {\mu}m', 'HorizontalAlignment', 'right')
text(1050, 320, '152 {\mu}m', 'HorizontalAlignment', 'right')

clearvars -except h

%% Plot organic-fluorous
axes(h(2))
files = dir('results/tol-HT230*05*.mat');
files = files(end:-1:1);
tit = '(b) organic-fluorous';
data = cell(length(files), 1);

for i = 1:length(files)
    exp = load(files(i).name);
    data{i} = exp.exp;
end

makeplot
legend OFF
text(1050, 1580, '1000 {\mu}m', 'HorizontalAlignment', 'right')
text(1050, 200, '152 {\mu}m', 'HorizontalAlignment', 'right')

clearvars -except h

%% Plot aqueous-organic
axes(h(3))
files = dir('results/H2O-tol*x05*.mat');
files = files(end:-1:1); % reverse order so legend makes sense
tit = '(c) aqueous-organic';
data = cell(length(files), 1);

for i = 1:length(files)
    exp = load(files(i).name);
    data{i} = exp.exp;
end

makeplot
legend OFF
text(930, 1850, '1000 {\mu}m', 'HorizontalAlignment', 'right')
text(1050, 200, '152 {\mu}m', 'HorizontalAlignment', 'right')

clearvars -except h

%% Appearance
set([h(2) h(3)], 'yticklabel', []); % no labels except for LHS plot
xlabel(h(1), '')
xlabel(h(3), '')
ylabel(h(2), '')
ylabel(h(3), '')

%% Legend
% Get entries that have been added automatically, but only want the first
% five as the rest are just the lines to guide the eye.
[legh, ~, ~, entires] = legend(h(3), 'Location', 'eastoutside');
entries = strrep({entires{1:5}}, 'um', '') ;
legh = legend(entries);

% Move legend to right hand side
pos = get(legh, 'position');
set(legh, 'position', [0.88 0.45 pos(3:4)])
h = text(1250, 1400, 'ID ({\mu}m)');

setprintformat