% Figure 7 (right)
% UV-visible absorption spectra of the feed (2), extract (3), and raffinate
% (4).

%% Load data
% Feed (2)
feed = importdata('results/extraction_spectra/feed.txt', '\t', 1);
feed = feed.data;

% Extract (3)
extract = importdata('results/extraction_spectra/extract.txt', '\t', 1);
extract = extract.data;
extract(:,2) = extract(:,2) * 3; % Diluted sample to fill cuvette, hence x3

% Raffinate (4)
raffinate = importdata('results/extraction_spectra/raffinate.txt', '\t', 1);
raffinate = raffinate.data;
raffinate(:,2) = raffinate(:,2) * 10; % x10 so you can see it.

%% Plot data
figure
pos = get(gcf,'Position');
pos(3:4) = [440 330];
set(gcf, 'position', pos)
hold on
plot(feed(:,1), feed(:,2), 'color', [1 0 1])
plot(extract(:,1), extract(:,2), 'r')
plot(raffinate(:,1), raffinate(:,2), 'k')
legend('feed', 'extract', 'raffinate')
xlabel('Wavelength (nm)')
ylabel('Absorbance')
axis([300 800 0 2.1])
box on
setprintformat
text(304, 0.25, '{\times}10', 'fontsize', 14)


%% Print maxima
% Wavelength of maximum absorption of feed
feed_lambda_max = feed(find(feed(:,2) == max(feed(200:end, 2))), 1);
% Absorbance at this wavelength for the feed and raffinate
feed_abs = feed(find(feed(:,1) == feed_lambda_max), 2);
raff_abs = raffinate(find(raffinate(:,1) == feed_lambda_max), 2);
fprintf('feed\t\t A(lambda = %i nm) =  %.3f\n', feed_lambda_max, feed_abs)
fprintf('raffinate\t A(lambda = %i nm) = %.3f\n', feed_lambda_max, ...
    raff_abs / 10)
fprintf('raffinate / feed =  %.3f\n', (raff_abs/10)/feed_abs)