% Figure 5
% Plot graph showing volumetric gollection rate of liquid at the outlet
% versus the volumetric injection rate of the solvent at the inlet for
% organic--fluorous separation, using flow restrictions of of common ID
% d = 254 microns and lengths of 2.5, 5, and 10 cm.

%% Load data
files = dir('results/tol-HT230_0254*.mat');
data = cell(length(files), 1);
legentry = cell(length(files), 1); % for legend entries

for i = 1:length(files)
    exp = load(files(i).name);
    data{i} = exp.exp;
    legentry{i} = strcat(num2str(data{i}.bp_length),' cm');
    
    % error checking
    assert(strcmpi(data{i}.dp,'toluene') == 1)
    assert(strcmpi(data{i}.cp,'ht230') == 1)
    assert(data{i}.dpdensity == 0.87)
    
    fprintf('loaded data for l = %.1f cm\n',data{i}.bp_length)
end

%% Plot data
h = figure;
makeplot

% Annotations
xpos = 1080;
l(1) = text(xpos, 980, '2.5 cm', 'color', colors(1,:));
l(2) = text(xpos, 586, '5 cm', 'color', colors(2,:));
l(3) = text(xpos, 472, '10 cm', 'color', colors(3,:));
annotation('textarrow',[800, 860]./1100,[970,970]./1100,'String','full recovery ')

% Appearance 
axis([50 1050 50 1050])
set(gca,'xtick',[100 400 700 1000])
legend OFF
axis square
setprintformat